:: ########################################################################################
::  Start
:: ########################################################################################
@echo off

:: ### Check Python3
call :info
echo * CHECKING FOR PYTHON3
echo.
echo ---
python --version
echo ---
echo.
if %errorlevel% neq 0 (
echo Python3 is not installed or cannot be found.
call :weiter "Press any key to start manually installation ..."
goto :install_python_pip
)
echo Python3 is installed
call :weiter

:: ###  Check Pip3
call :info
echo * CHECKING FOR PIP3
echo.
echo ---
pip3 --version
echo ---
echo.
if %errorlevel% neq 0 (
echo Pip3 is not installed or cannot be found.
call :weiter "Press any key to start a manual installation ..."
goto :install_python_pip
)
echo Pip3 is installed
echo.
echo * UPDATING PIP3
echo.
echo ---
python -m pip install --upgrade pip
echo ---
echo.
echo Pip3 is updated
call :weiter "Press any key to check install the required modules"

:: ###  Check Python modules
call :info
echo * INSTALLATION OF REQUIRED PYTHON MODULES
echo.
echo ---
pip install --user folium xlsxwriter psycopg2-binary PyQt5 PyQtWebEngine openpyxl requests psutil --upgrade
set errmod=%errorlevel%
echo ---
echo.
if %errmod% neq 0 goto :modtesterr
goto :modtestok
:modtesterr
echo Something went wrong ... Sorry ...
echo.
echo Please check the protocol an install everything manually ...
call :weiter "Press key to start information on manual installation"
goto :module_installation_error
:modtestok
echo All modules have been installed successfully
call :weiter

:: ###  Check Postgres Tools
call :info
echo * CHECKING FOR OPTIONAL POSTGRES COMMAND LINE TOOLS
echo.
echo This tools are optional. They are used for core administration, 
echo e.g. for making backups of the database. 
echo.
echo ---
psql --version
set errpsql=%errorlevel% 
pg_dump --version
set errpgdump=%errorlevel% 
echo ---
echo.
if %errpsql% neq 0 goto :pgtesterr
if %errpgdump% neq 0 goto :pgtesterr
goto :pgtestok
:pgtesterr
echo Not all PostgreSQL tools are found in your environmental system PATH.
echo This does not mean they are not installed. 
echo If they are installed but not added to the systems PATH ignore 
echo this message. 
echo You can set the path to them later in CRITTERBASE.
echo. 
echo -------------------------------------------------------------------
echo Do you want to install the tools now? 
echo -------------------------------------------------------------------
echo.
set /P ok=Install [y/n]? 
if %ok%==y (goto :install_postgres_tools) else (goto :startcritterbase)
:pgtestok
echo PostgreSQL command line tools have been found
call :weiter

:: ### Start CRITTERBASE und Ende
:startcritterbase
call :info
echo * STARTING CRITTERBASE
echo.
echo CRITTERBASE should open any second now ...
echo.
start /B python start.pyw
goto :ende

:: ########################################################################################
:: Functions
:: ########################################################################################

:: ###  Info: Weiter
:weiter
if [%1]==[] (set text="Press any key to proceed ...") else (set text=%1%)
set text=%text:"=%
echo.
echo ----------------------------------------------------
echo %text%
echo ----------------------------------------------------
pause >nul
exit /b 0

:: ###  Install Python/Pip
:install_python_pip
start "" https://www.python.org/download
call :info
echo * DOWNLOAD AND INSTALL PYTHON3 AND PIP3 MANUALLY
echo.
echo 1) Download the latest Python3 version (Version 3.5 or later) form 
echo    this location: "https://www.python.org/download"
echo    The website should have been opened in your browser now.
echo. 
echo 2) During installation ...
echo - ... first check "Add Python to PATH"
echo - ... then click on "Customize installation"
echo - ... check everything there
echo - ... click on "Next"
echo - ... in "Advanced Option" check "Associate files with Python"
echo - ... finally click on "Install"
echo - ... wait untill the installation is done.
echo.
echo 3) Quit this script and restart it manually.
call :weiter "Press any key to close this window ..."
::start cmd /c "install.bat"
goto :ende

:: ### Install PostgreSQL-Tools
:install_postgres_tools
start "" https://www.postgresql.org/download/windows/
call :info
echo * DOWNLOAD AND INSTALL OPTIONAL POSTGRES TOOLS
echo.
echo 1) Download the software form this location:
echo    "https://www.postgresql.org/download/windows/"
echo    The website should have been opened in your browser now.
echo    Click on "Download the installer".
echo    Download Version 10.6 for Windows x86-64 or 
echo    or Windows x86-32 depending on your system.
echo    Probably when using Windows 10 it is the 64 
echo    bit version.
echo.
echo 2) Start the installer and click "Next" until you
echo    reach the "Select Components" window.
echo    Do only select the "Command Line Tools" and click
echo    on "Next" until the installation starts.
echo.
echo 4) Using the File Explorer localize the path containing 
echo    the installed PostgreSQL tools.
echo    The path looks like this:
echo    "C:\Program Files\PostgreSQL\10\bin"
echo    This path is used later on in the CRITTERBASE Collector app.
echo.
echo 5) If you want to, add this path to your environmental PATH 
echo    doing the following steps:
echo    - Windows Desktop
echo    - Type in the search field (left bottom): env
echo    - Click on edit system environment variables
echo    - A window titled System Properties opens
echo    - Click on button environment variables
echo    - Click on PATH
echo    - Click on edit
echo    - Using ; as a separator, concatenate the path from 4) to
echo      the end of the PATH strings value field
echo    - Click on OK.. OK... OK
echo.
echo 3) Quit this script and restart it manually.
call :weiter "Press any key to close this window ..."
::start cmd /c "install.bat"
goto :ende

:: ###  Module installation error
:module_installation_error
call :info
echo * Manual installation information
echo.
echo Opening manual information in text editor.
echo %cd%
start notepad "readme.txt"
call :weiter "Press any key to close this window ..."
goto :ende

:: ###  Ende
:ende
exit /b 0

:: ###  Info
:info
@echo off
cls
echo.
echo ----------------------------------------------------
echo.
echo   ___ ___ ___ _____ _____ ___ ___ ___   _   ___ ___
echo  / __^| _ \_ _^|_   _^|_   _^| __^| _ \ _ ) /_\ / __^| __^|
echo ^| (__^|   /^| ^|  ^| ^|   ^| ^| ^| _^|^|   / _ \/ _ \\__ \ _^|
echo  \___^|_^|_\___^| ^|_^|   ^|_^| ^|___^|_^|_\___/_/ \_\___/___^|
echo.
echo.
echo                Guided Installation
echo.
echo ----------------------------------------------------
echo.
exit /b 0
